Documentation
¶
Index ¶
- type ClusterInfoImportLister
- type ClusterInfoImportListerExpansion
- type ClusterInfoImportNamespaceLister
- type ClusterInfoImportNamespaceListerExpansion
- type ClusterSetLister
- type ClusterSetListerExpansion
- type ClusterSetNamespaceLister
- type ClusterSetNamespaceListerExpansion
- type GatewayLister
- type GatewayListerExpansion
- type GatewayNamespaceLister
- type GatewayNamespaceListerExpansion
- type LabelIdentityLister
- type LabelIdentityListerExpansion
- type MemberClusterAnnounceLister
- type MemberClusterAnnounceListerExpansion
- type MemberClusterAnnounceNamespaceLister
- type MemberClusterAnnounceNamespaceListerExpansion
- type ResourceExportLister
- type ResourceExportListerExpansion
- type ResourceExportNamespaceLister
- type ResourceExportNamespaceListerExpansion
- type ResourceImportLister
- type ResourceImportListerExpansion
- type ResourceImportNamespaceLister
- type ResourceImportNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterInfoImportLister ¶ added in v1.7.0
type ClusterInfoImportLister interface {
// List lists all ClusterInfoImports in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ClusterInfoImport, err error)
// ClusterInfoImports returns an object that can list and get ClusterInfoImports.
ClusterInfoImports(namespace string) ClusterInfoImportNamespaceLister
ClusterInfoImportListerExpansion
}
ClusterInfoImportLister helps list ClusterInfoImports. All objects returned here must be treated as read-only.
func NewClusterInfoImportLister ¶ added in v1.7.0
func NewClusterInfoImportLister(indexer cache.Indexer) ClusterInfoImportLister
NewClusterInfoImportLister returns a new ClusterInfoImportLister.
type ClusterInfoImportListerExpansion ¶ added in v1.7.0
type ClusterInfoImportListerExpansion interface{}
ClusterInfoImportListerExpansion allows custom methods to be added to ClusterInfoImportLister.
type ClusterInfoImportNamespaceLister ¶ added in v1.7.0
type ClusterInfoImportNamespaceLister interface {
// List lists all ClusterInfoImports in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ClusterInfoImport, err error)
// Get retrieves the ClusterInfoImport from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ClusterInfoImport, error)
ClusterInfoImportNamespaceListerExpansion
}
ClusterInfoImportNamespaceLister helps list and get ClusterInfoImports. All objects returned here must be treated as read-only.
type ClusterInfoImportNamespaceListerExpansion ¶ added in v1.7.0
type ClusterInfoImportNamespaceListerExpansion interface{}
ClusterInfoImportNamespaceListerExpansion allows custom methods to be added to ClusterInfoImportNamespaceLister.
type ClusterSetLister ¶
type ClusterSetLister interface {
// List lists all ClusterSets in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ClusterSet, err error)
// ClusterSets returns an object that can list and get ClusterSets.
ClusterSets(namespace string) ClusterSetNamespaceLister
ClusterSetListerExpansion
}
ClusterSetLister helps list ClusterSets. All objects returned here must be treated as read-only.
func NewClusterSetLister ¶
func NewClusterSetLister(indexer cache.Indexer) ClusterSetLister
NewClusterSetLister returns a new ClusterSetLister.
type ClusterSetListerExpansion ¶
type ClusterSetListerExpansion interface{}
ClusterSetListerExpansion allows custom methods to be added to ClusterSetLister.
type ClusterSetNamespaceLister ¶
type ClusterSetNamespaceLister interface {
// List lists all ClusterSets in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ClusterSet, err error)
// Get retrieves the ClusterSet from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ClusterSet, error)
ClusterSetNamespaceListerExpansion
}
ClusterSetNamespaceLister helps list and get ClusterSets. All objects returned here must be treated as read-only.
type ClusterSetNamespaceListerExpansion ¶
type ClusterSetNamespaceListerExpansion interface{}
ClusterSetNamespaceListerExpansion allows custom methods to be added to ClusterSetNamespaceLister.
type GatewayLister ¶ added in v1.7.0
type GatewayLister interface {
// List lists all Gateways in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Gateway, err error)
// Gateways returns an object that can list and get Gateways.
Gateways(namespace string) GatewayNamespaceLister
GatewayListerExpansion
}
GatewayLister helps list Gateways. All objects returned here must be treated as read-only.
func NewGatewayLister ¶ added in v1.7.0
func NewGatewayLister(indexer cache.Indexer) GatewayLister
NewGatewayLister returns a new GatewayLister.
type GatewayListerExpansion ¶ added in v1.7.0
type GatewayListerExpansion interface{}
GatewayListerExpansion allows custom methods to be added to GatewayLister.
type GatewayNamespaceLister ¶ added in v1.7.0
type GatewayNamespaceLister interface {
// List lists all Gateways in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Gateway, err error)
// Get retrieves the Gateway from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Gateway, error)
GatewayNamespaceListerExpansion
}
GatewayNamespaceLister helps list and get Gateways. All objects returned here must be treated as read-only.
type GatewayNamespaceListerExpansion ¶ added in v1.7.0
type GatewayNamespaceListerExpansion interface{}
GatewayNamespaceListerExpansion allows custom methods to be added to GatewayNamespaceLister.
type LabelIdentityLister ¶ added in v1.9.0
type LabelIdentityLister interface {
// List lists all LabelIdentities in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.LabelIdentity, err error)
// Get retrieves the LabelIdentity from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.LabelIdentity, error)
LabelIdentityListerExpansion
}
LabelIdentityLister helps list LabelIdentities. All objects returned here must be treated as read-only.
func NewLabelIdentityLister ¶ added in v1.9.0
func NewLabelIdentityLister(indexer cache.Indexer) LabelIdentityLister
NewLabelIdentityLister returns a new LabelIdentityLister.
type LabelIdentityListerExpansion ¶ added in v1.9.0
type LabelIdentityListerExpansion interface{}
LabelIdentityListerExpansion allows custom methods to be added to LabelIdentityLister.
type MemberClusterAnnounceLister ¶
type MemberClusterAnnounceLister interface {
// List lists all MemberClusterAnnounces in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.MemberClusterAnnounce, err error)
// MemberClusterAnnounces returns an object that can list and get MemberClusterAnnounces.
MemberClusterAnnounces(namespace string) MemberClusterAnnounceNamespaceLister
MemberClusterAnnounceListerExpansion
}
MemberClusterAnnounceLister helps list MemberClusterAnnounces. All objects returned here must be treated as read-only.
func NewMemberClusterAnnounceLister ¶
func NewMemberClusterAnnounceLister(indexer cache.Indexer) MemberClusterAnnounceLister
NewMemberClusterAnnounceLister returns a new MemberClusterAnnounceLister.
type MemberClusterAnnounceListerExpansion ¶
type MemberClusterAnnounceListerExpansion interface{}
MemberClusterAnnounceListerExpansion allows custom methods to be added to MemberClusterAnnounceLister.
type MemberClusterAnnounceNamespaceLister ¶
type MemberClusterAnnounceNamespaceLister interface {
// List lists all MemberClusterAnnounces in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.MemberClusterAnnounce, err error)
// Get retrieves the MemberClusterAnnounce from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.MemberClusterAnnounce, error)
MemberClusterAnnounceNamespaceListerExpansion
}
MemberClusterAnnounceNamespaceLister helps list and get MemberClusterAnnounces. All objects returned here must be treated as read-only.
type MemberClusterAnnounceNamespaceListerExpansion ¶
type MemberClusterAnnounceNamespaceListerExpansion interface{}
MemberClusterAnnounceNamespaceListerExpansion allows custom methods to be added to MemberClusterAnnounceNamespaceLister.
type ResourceExportLister ¶
type ResourceExportLister interface {
// List lists all ResourceExports in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ResourceExport, err error)
// ResourceExports returns an object that can list and get ResourceExports.
ResourceExports(namespace string) ResourceExportNamespaceLister
ResourceExportListerExpansion
}
ResourceExportLister helps list ResourceExports. All objects returned here must be treated as read-only.
func NewResourceExportLister ¶
func NewResourceExportLister(indexer cache.Indexer) ResourceExportLister
NewResourceExportLister returns a new ResourceExportLister.
type ResourceExportListerExpansion ¶
type ResourceExportListerExpansion interface{}
ResourceExportListerExpansion allows custom methods to be added to ResourceExportLister.
type ResourceExportNamespaceLister ¶
type ResourceExportNamespaceLister interface {
// List lists all ResourceExports in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ResourceExport, err error)
// Get retrieves the ResourceExport from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ResourceExport, error)
ResourceExportNamespaceListerExpansion
}
ResourceExportNamespaceLister helps list and get ResourceExports. All objects returned here must be treated as read-only.
type ResourceExportNamespaceListerExpansion ¶
type ResourceExportNamespaceListerExpansion interface{}
ResourceExportNamespaceListerExpansion allows custom methods to be added to ResourceExportNamespaceLister.
type ResourceImportLister ¶
type ResourceImportLister interface {
// List lists all ResourceImports in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ResourceImport, err error)
// ResourceImports returns an object that can list and get ResourceImports.
ResourceImports(namespace string) ResourceImportNamespaceLister
ResourceImportListerExpansion
}
ResourceImportLister helps list ResourceImports. All objects returned here must be treated as read-only.
func NewResourceImportLister ¶
func NewResourceImportLister(indexer cache.Indexer) ResourceImportLister
NewResourceImportLister returns a new ResourceImportLister.
type ResourceImportListerExpansion ¶
type ResourceImportListerExpansion interface{}
ResourceImportListerExpansion allows custom methods to be added to ResourceImportLister.
type ResourceImportNamespaceLister ¶
type ResourceImportNamespaceLister interface {
// List lists all ResourceImports in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ResourceImport, err error)
// Get retrieves the ResourceImport from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ResourceImport, error)
ResourceImportNamespaceListerExpansion
}
ResourceImportNamespaceLister helps list and get ResourceImports. All objects returned here must be treated as read-only.
type ResourceImportNamespaceListerExpansion ¶
type ResourceImportNamespaceListerExpansion interface{}
ResourceImportNamespaceListerExpansion allows custom methods to be added to ResourceImportNamespaceLister.