Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterClaimLister ¶
type ClusterClaimLister interface {
// List lists all ClusterClaims in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.ClusterClaim, err error)
// ClusterClaims returns an object that can list and get ClusterClaims.
ClusterClaims(namespace string) ClusterClaimNamespaceLister
ClusterClaimListerExpansion
}
ClusterClaimLister helps list ClusterClaims. All objects returned here must be treated as read-only.
func NewClusterClaimLister ¶
func NewClusterClaimLister(indexer cache.Indexer) ClusterClaimLister
NewClusterClaimLister returns a new ClusterClaimLister.
type ClusterClaimListerExpansion ¶
type ClusterClaimListerExpansion interface{}
ClusterClaimListerExpansion allows custom methods to be added to ClusterClaimLister.
type ClusterClaimNamespaceLister ¶
type ClusterClaimNamespaceLister interface {
// List lists all ClusterClaims in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.ClusterClaim, err error)
// Get retrieves the ClusterClaim from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha2.ClusterClaim, error)
ClusterClaimNamespaceListerExpansion
}
ClusterClaimNamespaceLister helps list and get ClusterClaims. All objects returned here must be treated as read-only.
type ClusterClaimNamespaceListerExpansion ¶
type ClusterClaimNamespaceListerExpansion interface{}
ClusterClaimNamespaceListerExpansion allows custom methods to be added to ClusterClaimNamespaceLister.
type ClusterSetLister ¶ added in v1.13.0
type ClusterSetLister interface {
// List lists all ClusterSets in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.ClusterSet, err error)
// ClusterSets returns an object that can list and get ClusterSets.
ClusterSets(namespace string) ClusterSetNamespaceLister
ClusterSetListerExpansion
}
ClusterSetLister helps list ClusterSets. All objects returned here must be treated as read-only.
func NewClusterSetLister ¶ added in v1.13.0
func NewClusterSetLister(indexer cache.Indexer) ClusterSetLister
NewClusterSetLister returns a new ClusterSetLister.
type ClusterSetListerExpansion ¶ added in v1.13.0
type ClusterSetListerExpansion interface{}
ClusterSetListerExpansion allows custom methods to be added to ClusterSetLister.
type ClusterSetNamespaceLister ¶ added in v1.13.0
type ClusterSetNamespaceLister interface {
// List lists all ClusterSets in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.ClusterSet, err error)
// Get retrieves the ClusterSet from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha2.ClusterSet, error)
ClusterSetNamespaceListerExpansion
}
ClusterSetNamespaceLister helps list and get ClusterSets. All objects returned here must be treated as read-only.
type ClusterSetNamespaceListerExpansion ¶ added in v1.13.0
type ClusterSetNamespaceListerExpansion interface{}
ClusterSetNamespaceListerExpansion allows custom methods to be added to ClusterSetNamespaceLister.